.. -*- mode: rst -*-

People
------

This work is made available by a community of people, including:

* `Bertrand Thirion <https://github.com/bthirion>`_
* `Denis Fouchard <https://github.com/denisfouchard>`_
* `Elizabeth DuPre <https://github.com/emdupre>`_
* `Hugo Richard <https://github.com/hugorichard>`_
* `Kshitij Chawla <https://github.com/kchawla-pi>`_
* `Pierre-Louis Barbarant <https://github.com/pbarbarant>`_
* `Thomas Bazeille <https://github.com/thomasbazeille>`_


Funding
.......

This project has received funding from the European Union's Horizon
2020 Research and Innovation Programme under Grant Agreement No. 785907
(HBP SGA2) and `Digiteo <https://fr.wikipedia.org/wiki/Digiteo>`_.

.. _citing:

Citing Nilearn and scikit-learn
-------------------------------

This package can be lightweight and efficient because it relies on great toolboxes,
notably :nilearn:`nilearn <>` and :sklearn:`scikit-learn <>`.

A huge amount of work goes into both of these packages.
Researchers who invest their time in developing and maintaining the package
deserve recognition with citations.
In addition, the :inria:`INRIA MIND Project Team <mind>` needs citations
to the paper in order to justify paying a software engineer on the project.
To guarantee the future of the toolkit, if you use it, please cite it.

Citing nilearn
..............

If you want to cite Nilearn, we suggest you do it using our Zenodo DOI:

.. code-block:: bibtex

    @software{Nilearn,
        author = {Nilearn contributors},
        license = {BSD-4-Clause},
        title = {{nilearn}},
        url = {https://github.com/nilearn/nilearn},
        doi = {https://doi.org/10.5281/zenodo.8397156}
    }

Nilearn's Research Resource Identifier (RRID) is:
`RRID:SCR_001362 <https://scicrunch.org/resources/data/record/nlx_144509-1/SCR_001362/resolver?q=nilearn&l=nilearn&i=rrid:scr_001362>`_

There is no paper published about nilearn.
However, the patterns underlying the package have been described in:
`Machine learning for neuroimaging with scikit-learn <https://doi.org/10.3389/fninf.2014.00014>`_.


Citing scikit-learn
...................
To cite :sklearn:`scikit-learn <>`, please see the scikit-learn documentation on
:sklearn:`how to cite <about.html#citing-scikit-learn>`.
